x_decorator
===================================

X Decorator is a python package for decorators that used for a variety of purposes, such as logging, memoization, and
more.


Setup
-----

You can install this package by using the pip tool and installing:

    $ pip install x-decorator


Docs
---------

See docs:- https://shokr.github.io/x_decorator/.
